=======
History
=======

0.1.0 (2019-05-06)
------------------

* First release on PyPI.

0.2.0 (2019-05-08)
------------------

* More Examples from `Click Documentation`_.
* Testing Click Commands using click.testing.CliRunner




.. _`Click Documentation` : https://click.palletsprojects.com/en/7.x/options/
